==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListDescription } from "./WebListDescription";
/**
 * @hidden
 */
var WebListDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebListDescriptionMetadata, _super);
    function WebListDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListDescriptionMetadata.b = function (a) {
        if (WebListDescriptionMetadata.a == null) {
            WebListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListDescriptionMetadata.c(WebListDescriptionMetadata.a);
        }
        if (a.k(WebListDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:List");
        a.item("__tagNameWC", "String:igc-list");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
    };
    WebListDescriptionMetadata.d = function (a) {
        WebListDescriptionMetadata.b(a);
        a.ad("WebList", function () { return new WebListDescription(); });
        a.ac("WebList", WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.$t = markType(WebListDescriptionMetadata, 'WebListDescriptionMetadata');
    WebListDescriptionMetadata.a = null;
    return WebListDescriptionMetadata;
}(Base));
export { WebListDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListDescription } from "./WebListDescription";
/**
 * @hidden
 */
var WebListDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebListDescriptionMetadata, _super);
    function WebListDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListDescriptionMetadata.b = function (a) {
        if (WebListDescriptionMetadata.a == null) {
            WebListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListDescriptionMetadata.c(WebListDescriptionMetadata.a);
        }
        if (a.k(WebListDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:List");
        a.item("__tagNameWC", "String:igc-list");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebListDescriptionMetadata.d = function (a) {
        WebListDescriptionMetadata.b(a);
        a.ae("WebList", function () { return new WebListDescription(); });
        a.ad("WebList", WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.$t = markType(WebListDescriptionMetadata, 'WebListDescriptionMetadata');
    WebListDescriptionMetadata.a = null;
    return WebListDescriptionMetadata;
}(Base));
export { WebListDescriptionMetadata };
